@@ -59,23 +59,58 @@ class complexFn:
 	def __neg__(self):
 		return complexFn([0, self], "-")
 
+	# Boolean Evaluation
+	def __bool__(self):
+		return any(self.param)
+
 	def __repr__(self):
 		result, param, op, power = "", self.param, self.op, self.power
 
 		if any(param):
-			u, v = param[0], param[1]
+			u, v, result = param[0], param[1], ""
 
-			if bool(str(u)):
-				if op == "/":
-					result = f"({u}{op}{v})"
+			if bool(repr(u)) and (u != 0) and (u != 1):
+				result += f"{u}"
+			elif u == 0:
+				if op == "-":
+					result += f"-"
+				elif op in ("*", "/"):
+					return "0"
+			elif u == 1:
+				if op != "*":
+					result += f"1"
+
+			# Operator Representation
+			if any(result):
+				if result != "-":
+					if op == "/":
+						result += f"{op}"
+					else:
+						result += f" {op}"
 				else:
-					result = f"({u} {op} {v})"
+
+					# Unary Negation Representation
+					result = f"(-{v})"
+
+					if power == 1:
+						return str(result)
+					elif power == 0.5:
+						return f"sqrt({result})"
+					else:
+						return f"{result}^{power}"
+
+			# Second Term Representation
+			if v != 1:
+				if op == "/":
+					result += f"{v}"
+				else:
+					result += f" {v}"
+			elif (v == 1) and (op in ("+", "-")):
+				result += f" 1"
 			else:
-				if op == "/":
-					result = f"({None}{op}{v})"
-				else:
-					result = f"({None} {op} {v})"
+				result = result[::-1][2:][::-1]
 
+			# Power Representation
 			if power == 1:
 				return str(result)
 			elif power == 0.5:
